@@ -4,22 +4,22 @@ use strict;
 
 use Devel::Examine::Subs;
 
-my %params = (
+my $params = {
                 file => '../t/sample.data', 
                 engine => 'has', 
                 search => 'this',
                 core_dump => 1,
-              );
+              };
 
-my $des = Devel::Examine::Subs->new(%params);
+my $des = Devel::Examine::Subs->new($params);
 
-my $has = $des->run(\%params);
+my $has = $des->run($params);
 
 print "$_\n" for @$has;
 
-$has = $des->has(
+$has = $des->has({
                 file => '../t/sample.data', 
                 search => 'this',
-);
+});
 
 print scalar(@$has) . "\n";
