@@ -2,7 +2,7 @@ package Devel::Examine::Subs;
 use warnings; 
 use strict;
 
-our $VERSION = '1.26';
+our $VERSION = '1.27';
 
 use Carp; 
 use Data::Dumper; 
@@ -21,8 +21,11 @@ sub new {
     
     my $p = shift;
 
+    # default configs
+
     $self->{namespace} = 'Devel::Examine::Subs';
-    
+    $self->{params}{regex} = 1;
+
     $self->_config($p);
 
     return $self;
@@ -42,7 +45,7 @@ sub run {
     # do something different for a dir
 
     if ($self->{params}{directory}){
-        my $files = $self->run_directory();
+        my $files = $self->run_directory;
     }
     else {
         $self->_core($self->{params});
@@ -79,7 +82,8 @@ sub run_directory {
 
                         push @files, $file;
                       },
-                        no_chdir => 1 }, $dir );
+                        no_chdir => 1 
+                    }, $dir );
 
     my %struct;
     
@@ -97,7 +101,7 @@ sub run_directory {
     # we've got to clean up core/config here
 
     $self->_run_end(1);    
-    $self->_clean_core_config();
+    $self->_clean_core_config;
 
     return \%struct;
 }
@@ -134,6 +138,7 @@ sub _config {
         exclude => 0,
         lines => 0,
         module => 0,
+        objects_in_hash => 0,
         pre_proc_dump => 0,
         pre_filter_dump => 0,
         engine_dump => 0,
@@ -172,7 +177,7 @@ sub _clean_config {
 
     for my $var (keys %$config_vars){
        
-        last if ! $self->_run_end();
+        last if ! $self->_run_end;
 
         # skip if it's a persistent var
 
@@ -185,6 +190,7 @@ sub _clean_config {
 
     for my $param (keys %$p){
         if (! exists $config_vars->{$param}){
+            # warn "\n\nDES::_clean_config() deleting invalid param: $param\n\n";
             delete $p->{$param};
         }
     }
@@ -275,7 +281,7 @@ sub _core {
     my $data;
 
     if ($self->{params}{pre_proc}){
-        my $pre_proc = $self->_pre_proc();
+        my $pre_proc = $self->_pre_proc;
 
         $data = $pre_proc->($p);
 
@@ -289,7 +295,7 @@ sub _core {
 
     # processor
 
-    my $subs = $self->_subs();
+    my $subs = $self->_subs;
     
     $subs = $subs // 0;
 
@@ -300,7 +306,7 @@ sub _core {
     # pre engine filter
 
     if ($self->{params}{pre_filter}){
-        for my $pre_filter ($self->_pre_filter()){
+        for my $pre_filter ($self->_pre_filter){
             $subs = $pre_filter->($p, $subs);
             $self->{data} = $subs;
         }
@@ -336,7 +342,7 @@ sub _core {
     # run_directory() takes care of cleanup if it's enabled
 
     $self->_run_end(1) if ! $self->{params}{directory};
-    $self->_clean_core_config() if ! $self->{params}{directory};
+    $self->_clean_core_config if ! $self->{params}{directory};
 
     $self->{data} = $subs;
     return $subs;
@@ -436,7 +442,7 @@ sub _pre_proc {
     
     if (not ref($pre_proc) eq 'CODE'){
         my $pre_proc_module = $self->{namespace} . "::Preprocessor";
-        my $compiler = $pre_proc_module->new();
+        my $compiler = $pre_proc_module->new;
 
         if (! $compiler->exists($pre_proc)){
             croak "Devel::Examine::Subs::_pre_proc() speaking...\n\n" .
@@ -508,7 +514,7 @@ sub _pre_filter {
 
             if (not ref($pf) eq 'CODE'){
                 my $pre_filter_module = $self->{namespace} . "::Prefilter";
-                my $compiler = $pre_filter_module->new();
+                my $compiler = $pre_filter_module->new;
 
                 # pre_filter isn't in the dispatch table
 
@@ -573,7 +579,7 @@ sub _engine {
         # engine is a name
 
         my $engine_module = $self->{namespace} . "::Engine";
-        my $compiler = $engine_module->new();
+        my $compiler = $engine_module->new;
 
         # engine isn't in the dispatch table
 
@@ -620,11 +626,11 @@ sub pre_procs {
 
     my $self = shift;
     my $module = $self->{namespace} . "::Preprocessor";
-    my $pre_proc = $module->new();
+    my $pre_proc = $module->new;
 
     my @pre_procs;
 
-    for (keys %{$pre_proc->_dt()}){
+    for (keys %{$pre_proc->_dt}){
         push @pre_procs, $_ if $_ !~ /^_/;
     }
     return @pre_procs;
@@ -633,11 +639,11 @@ sub pre_filters {
 
     my $self = shift;
     my $module = $self->{namespace} . "::Prefilter";
-    my $pre_filter = $module->new();
+    my $pre_filter = $module->new;
 
     my @pre_filters;
 
-    for (keys %{$pre_filter->_dt()}){
+    for (keys %{$pre_filter->_dt}){
         push @pre_filters, $_ if $_ !~ /^_/;
     }
     return @pre_filters;
@@ -646,11 +652,11 @@ sub engines {
 
     my $self = shift;
     my $module = $self->{namespace} . "::Engine";
-    my $engine = $module->new();
+    my $engine = $module->new;
  
     my @engines;
 
-    for (keys %{$engine->_dt()}){
+    for (keys %{$engine->_dt}){
         push @engines, $_ if $_ !~ /^_/;
     }
     return @engines;
@@ -663,7 +669,7 @@ sub has {
     $self->{params}{pre_filter} = 'file_lines_contain';
     $self->{params}{engine} = 'has';
     $self->_config($p);
-    $self->run();
+    $self->run;
 }
 sub missing {
 
@@ -672,7 +678,7 @@ sub missing {
 
     $self->{params}{engine} = 'missing';
     $self->_config($p);
-    $self->run();
+    $self->run;
 }
 sub all {
 
@@ -681,7 +687,7 @@ sub all {
 
     $self->{params}{engine} = 'all';
     $self->_config($p);
-    $self->run();
+    $self->run;
 }
 sub lines {
 
@@ -695,7 +701,7 @@ sub lines {
         $self->{params}{pre_filter} = 'file_lines_contain';
     }
 
-    $self->run();
+    $self->run;
 }
 sub module {
 
@@ -711,7 +717,7 @@ sub module {
 
     $self->{params}{engine} = 'module';
 
-    $self->run();
+    $self->run;
 }
 sub objects {
 
@@ -723,7 +729,7 @@ sub objects {
     $self->{params}{pre_filter} = 'subs';
     $self->{params}{engine} = 'objects';
 
-    $self->run();
+    $self->run;
 }
 sub search_replace {
 
@@ -737,7 +743,7 @@ sub search_replace {
 
     $self->{params}{engine} = 'search_replace';
 
-    $self->run();
+    $self->run;
 }
 sub inject_after {
 
@@ -753,7 +759,7 @@ sub inject_after {
 
     $self->{params}{engine} = 'inject_after';
 
-    $self->run();
+    $self->run;
 }
 sub add_functionality {
     
@@ -785,7 +791,7 @@ sub add_functionality {
                       },
     );
 
-    my $caller = (caller())[1];
+    my $caller = (caller)[1];
 
     open my $fh, '<', $caller
       or confess "can't open the caller file $caller: $!";
@@ -815,7 +821,7 @@ sub add_functionality {
     tie my @TIE_file, 'Tie::File', $file
       or croak "can't Tie::File the file $file: $!";
 
-    my $end_line = $des->run();
+    my $end_line = $des->run;
 
     push @TIE_file, @code;
 }
@@ -834,7 +840,7 @@ Devel::Examine::Subs - Get info, search/replace and inject code in Perl file sub
 
     use Devel::Examine::Subs;
 
-    my $file = 'perl.pl'; # or directory, or module name (D::E::S)
+    my $file = 'perl.pl'; # or directory, or Module::Name
     my $search = 'string';
 
     my $des = Devel::Examine::Subs->new({file => $file);
@@ -848,7 +854,7 @@ Get all the subs as objects
         $sub->name;       # name of sub
         $sub->start;      # number of first line in sub
         $sub->end;        # number of last line in sub
-        $sub->num_lines;  # number of lines in sub
+        $sub->line_count; # number of lines in sub
         $sub->code;       # entire sub code from file
         $sub->lines;      # lines that match search term
 
@@ -864,11 +870,11 @@ Get all subs containing "string" in the body
 
     my $aref = $des->has({search => $search});
 
-Search and replace code in subs (escape special chars unless using 'regex' param)
+Search and replace code in subs
 
     $des->search_replace({
-                    search => "$template = 'one.tmpl'",
-                    replace => "$template = 'two.tmpl'",
+                    search => q/\$template = 'one\.tmpl'",
+                    replace => '$template = \'two.tmpl\'',
                   });
 
 Inject code into sub after a search term (preserves previous line's indenting)
@@ -894,7 +900,7 @@ Print out all lines in all subs that contain a search term
 
     for my $sub (@$subs){
     
-        my $lines_with_search_term = $sub->lines();
+        my $lines_with_search_term = $sub->lines;
 
         for (@$lines_with_search_term){
             my ($line_num, $text) = split /:/, $_, 2;
@@ -1020,7 +1026,11 @@ The exact opposite of has.
 
 Mandatory parameters: None
 
-Returns an array reference of subroutine objects. See L<SYNOPSIS> for the structure of each object.
+Optional parameters: C<{objects_in_hash => 1}>
+
+Returns an array reference of subroutine objects. If the optional C<objects_in_hash> is sent in with a true value, the objects will be returned in a hash reference where the key is the sub's name, and the value is the sub object.
+
+See L<SYNOPSIS> for the structure of each object.
 
 
 
