@@ -5,7 +5,7 @@ use strict; use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.26';
+our $VERSION = '1.27';
 
 sub new {
 
@@ -14,7 +14,7 @@ sub new {
 
     my $struct = shift;
 
-    $self->{pre_procs} = $self->_dt();
+    $self->{pre_procs} = $self->_dt;
 
     return $self;
 }
